package org.jeecg.modules.alUser.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.xkcoding.http.HttpUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.util.RedisUtil;
import org.jeecg.config.shiro.ShiroRealm;
import org.jeecg.modules.alUser.service.IndexService;
import org.jeecg.modules.banner.entity.WebBanner;
import org.jeecg.modules.hanHaiMember.entity.HanHaiMember;
import org.jeecg.modules.postBean.SuggestReq;
import org.jeecg.modules.tbSuggest.entity.TbSuggest;
import org.jeecg.modules.tbSuggest.service.ITbSuggestService;
import org.jeecg.modules.utils.ValidateTool;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Author scott
 * @since 2018-12-17
 */
@RestController
@RequestMapping("/index")
@Api(tags = "首页等展示接口")
@Slf4j
public class IndexController {
    @Autowired
    private ITbSuggestService tbSuggestService;
    @Autowired
    private IndexService indexService;
    @Autowired
    private ShiroRealm shiroRealm;
    @Autowired
    private RedisUtil redisUtil;


    @ApiOperation(value = "铝价接口")
    @RequestMapping(value = "/alprice", method = RequestMethod.POST)
    public Result<JSONObject> alprice() {
        String alprice = null;
        Object o = redisUtil.get(CommonConstant.AL_PRICE);
        if (ValidateTool.isNull(o)) {
            alprice = HttpUtil.get("https://www.alphavantage.co/query?function=ALUMINUM&interval=monthly&apikey=AH6NDLVPBHJ8K7OM");
            //每天更新一次缓存
            redisUtil.set(CommonConstant.AL_PRICE, alprice, 86400);
        } else {
            alprice = String.valueOf(o);
        }
        JSONObject jsonObject = JSONObject.parseObject(alprice);
        Object data = jsonObject.get("data");
        List<JSONObject> strings = JSON.parseArray(String.valueOf(data), JSONObject.class);
        //取前12条数据返回
        List<JSONObject> collect = strings.stream().limit(12).collect(Collectors.toList());
        jsonObject.put("data", collect);
        return Result.ok(jsonObject);
    }

    @ApiOperation(value = "我的头像昵称，平台客户电话等信息")
    @RequestMapping(value = "/index", method = RequestMethod.POST)
    public Result index(@RequestHeader("X-Access-Token") String token) {

        Result<?> indexInfo = indexService.getIndexInfo(token);

        return indexInfo;
    }


    @ApiOperation(value = "获取banner列表")
    @RequestMapping(value = "/bannerList", method = RequestMethod.POST)
    public Result<Map<Integer, List<WebBanner>>> bannerList(@RequestHeader(value = "X-Access-Token", required = false) String token) {

        return indexService.bannerList();
    }


    @ApiOperation(value = "帮助与反馈", notes = "帮助与反馈")
    @PostMapping(value = "/addSuggest")
    public Result<String> addSuggest(@RequestBody SuggestReq tbSuggest, @RequestHeader("X-Access-Token") String token) {
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiAccount(token);
        TbSuggest tbSuggest1 = new TbSuggest();
        BeanUtils.copyProperties(tbSuggest, tbSuggest1);
        tbSuggest1.setUserId(hanHaiMember.getId());
        tbSuggestService.save(tbSuggest1);
        return Result.OK("添加成功！");
    }


    @ApiOperation(value = "获取平台隐私政策，协议等")
    @RequestMapping(value = "/getSysText", method = RequestMethod.POST)
    public Result getSysText(@RequestHeader(value = "X-Access-Token", required = false) String token) {

        Result<?> indexInfo = indexService.getSysText(token);

        return indexInfo;
    }

}
